'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var randomStrings = require('./utils/randomStrings.cjs');
var errors = require('./errors/errors.cjs');

const createGenericFile = (content, fileName, options = {}) => ({
  buffer: typeof content === 'string' ? new TextEncoder().encode(content) : content,
  fileName,
  displayName: options.displayName ?? fileName,
  uniqueName: options.uniqueName ?? randomStrings.generateRandomString(),
  contentType: options.contentType ?? null,
  extension: options.extension ?? getExtension(fileName),
  tags: options.tags ?? []
});
const createGenericFileFromBrowserFile = async (browserFile, options = {}) => createGenericFile(new Uint8Array(await browserFile.arrayBuffer()), browserFile.name, options);
const createGenericFileFromJson = (json, fileName = 'inline.json', options = {}) => {
  let jsonString;
  try {
    jsonString = JSON.stringify(json);
  } catch (error) {
    throw new errors.InvalidJsonVariableError(error);
  }
  return createGenericFile(jsonString, fileName, options);
};
const createBrowserFileFromGenericFile = file => new File([file.buffer], file.fileName);
const getBytesFromGenericFiles = (...files) => files.reduce((acc, file) => acc + file.buffer.byteLength, 0);
const isGenericFile = file => file != null && typeof file === 'object' && 'buffer' in file && 'fileName' in file && 'displayName' in file && 'uniqueName' in file && 'contentType' in file && 'extension' in file && 'tags' in file;
const getExtension = fileName => {
  const lastDotIndex = fileName.lastIndexOf('.');
  return lastDotIndex < 0 ? null : fileName.slice(lastDotIndex + 1);
};

exports.createBrowserFileFromGenericFile = createBrowserFileFromGenericFile;
exports.createGenericFile = createGenericFile;
exports.createGenericFileFromBrowserFile = createGenericFileFromBrowserFile;
exports.createGenericFileFromJson = createGenericFileFromJson;
exports.getBytesFromGenericFiles = getBytesFromGenericFiles;
exports.isGenericFile = isGenericFile;
//# sourceMappingURL=GenericFile.cjs.map
