'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var bytes = require('./utils/bytes.cjs');

const PUBLIC_KEY_LENGTH = 32;
const publicKey = input => {
  let key;
  // PublicKeyBase58.
  if (typeof input === 'string') {
    key = {
      bytes: bytes.base58.serialize(input)
    };
  }
  // { publicKey: PublicKey }.
  else if (typeof input === 'object' && 'publicKey' in input) {
    key = {
      bytes: new Uint8Array(input.publicKey.bytes)
    };
  }
  // PublicKey.
  else if (isPublicKey(input)) {
    key = {
      bytes: new Uint8Array(input.bytes)
    };
  }
  // PublicKeyBytes.
  else {
    key = {
      bytes: new Uint8Array(input)
    };
  }
  assertPublicKey(key);
  return key;
};
const defaultPublicKey = () => publicKey('11111111111111111111111111111111');
const isPublicKey = value => typeof value === 'object' && typeof value.bytes === 'object' && typeof value.bytes.BYTES_PER_ELEMENT === 'number' && typeof value.bytes.length === 'number' && value.bytes.BYTES_PER_ELEMENT === 1 && value.bytes.length === PUBLIC_KEY_LENGTH;
const isPda = value => typeof value === 'object' && typeof value.bump === 'number' && isPublicKey(value);
function assertPublicKey(value) {
  if (!isPublicKey(value)) {
    throw new Error('Invalid public key');
  }
}
const samePublicKey = (left, right) => left.bytes.toString() === right.bytes.toString();
const formatPublicKey = publicKey => bytes.base58.deserialize(publicKey.bytes)[0];
const checkForIsWritableOverride = (account, value) => 'isWritable' in account && typeof account.isWritable === 'boolean' ? account.isWritable : value;

exports.PUBLIC_KEY_LENGTH = PUBLIC_KEY_LENGTH;
exports.assertPublicKey = assertPublicKey;
exports.checkForIsWritableOverride = checkForIsWritableOverride;
exports.defaultPublicKey = defaultPublicKey;
exports.formatPublicKey = formatPublicKey;
exports.isPda = isPda;
exports.isPublicKey = isPublicKey;
exports.publicKey = publicKey;
exports.samePublicKey = samePublicKey;
//# sourceMappingURL=PublicKey.cjs.map
