import { BigIntInput } from './BigInt';
import { Serializer } from './Serializer';
export type AmountIdentifier = 'SOL' | 'USD' | '%' | 'splToken' | string;
export type AmountDecimals = number;
export type Amount<I extends AmountIdentifier = AmountIdentifier, D extends AmountDecimals = AmountDecimals> = {
    /** The amount in its lower possible unit such that it does not contain decimals. */
    basisPoints: bigint;
    /** The identifier of the amount. */
    identifier: I;
    /** The number of decimals in the amount. */
    decimals: D;
};
export type SolAmount = Amount<'SOL', 9>;
export type UsdAmount = Amount<'USD', 2>;
export type PercentAmount<D extends AmountDecimals> = Amount<'%', D>;
export declare const createAmount: <I extends string, D extends number>(basisPoints: BigIntInput, identifier: I, decimals: D) => Amount<I, D>;
export declare const createAmountFromDecimals: <I extends string, D extends number>(decimalAmount: number, identifier: I, decimals: D) => Amount<I, D>;
export declare const tokenAmount: <I extends string, D extends number>(tokens: number, identifier?: I | undefined, decimals?: D | undefined) => Amount<I, D>;
export declare const lamports: (lamports: BigIntInput) => SolAmount;
export declare const sol: (sol: number) => SolAmount;
export declare const usd: (usd: number) => UsdAmount;
export declare const isAmount: <I extends string, D extends number>(amount: Amount, identifier: I, decimals: D) => amount is Amount<I, D>;
export declare const isSolAmount: (amount: Amount) => amount is SolAmount;
export declare const sameAmounts: (left: Amount, right: Amount) => boolean;
export declare function assertAmount<I extends AmountIdentifier, D extends AmountDecimals>(amount: Amount, identifier: I, decimals: D): asserts amount is Amount<I, D>;
export declare function assertSolAmount(actual: Amount): asserts actual is SolAmount;
export declare function assertSameAmounts(left: Amount, right: Amount, operation?: string): void;
export declare const addAmounts: <I extends string, D extends number>(left: Amount<I, D>, right: Amount<I, D>) => Amount<I, D>;
export declare const subtractAmounts: <I extends string, D extends number>(left: Amount<I, D>, right: Amount<I, D>) => Amount<I, D>;
export declare const multiplyAmount: <I extends string, D extends number>(left: Amount<I, D>, multiplier: number | bigint) => Amount<I, D>;
export declare const divideAmount: <I extends string, D extends number>(left: Amount<I, D>, divisor: number | bigint) => Amount<I, D>;
export declare const absoluteAmount: <I extends string, D extends number>(value: Amount<I, D>) => Amount<I, D>;
export declare const compareAmounts: <I extends string, D extends number>(left: Amount<I, D>, right: Amount<I, D>) => -1 | 0 | 1;
export declare const isEqualToAmount: <I extends string, D extends number>(left: Amount<I, D>, right: Amount<I, D>, tolerance?: Amount<I, D> | undefined) => boolean;
export declare const isLessThanAmount: <I extends string, D extends number>(left: Amount<I, D>, right: Amount<I, D>) => boolean;
export declare const isLessThanOrEqualToAmount: <I extends string, D extends number>(left: Amount<I, D>, right: Amount<I, D>) => boolean;
export declare const isGreaterThanAmount: <I extends string, D extends number>(left: Amount<I, D>, right: Amount<I, D>) => boolean;
export declare const isGreaterThanOrEqualToAmount: <I extends string, D extends number>(left: Amount<I, D>, right: Amount<I, D>) => boolean;
export declare const isZeroAmount: (value: Amount) => boolean;
export declare const isPositiveAmount: (value: Amount) => boolean;
export declare const isNegativeAmount: (value: Amount) => boolean;
export declare const amountToString: (value: Amount, maxDecimals?: number) => string;
export declare const amountToNumber: (value: Amount) => number;
export declare const formatAmount: (value: Amount, maxDecimals?: number) => string;
export declare const mapAmountSerializer: <I extends string = string, D extends number = number>(serializer: Serializer<number> | Serializer<number | bigint, bigint>, identifier: I, decimals: D) => Serializer<Amount<I, D>, Amount<I, D>>;
