import type { Context } from './Context';
import type { Keypair } from './KeyPair';
import { PublicKey } from './PublicKey';
import { Transaction } from './Transaction';
export type Signer = {
    publicKey: PublicKey;
    signMessage(message: Uint8Array): Promise<Uint8Array>;
    signTransaction(transaction: Transaction): Promise<Transaction>;
    signAllTransactions(transactions: Transaction[]): Promise<Transaction[]>;
};
export declare const signTransaction: (transaction: Transaction, signers: Signer[]) => Promise<Transaction>;
export declare const signAllTransactions: (transactionsWithSigners: {
    transaction: Transaction;
    signers: Signer[];
}[]) => Promise<Transaction[]>;
export declare const isSigner: (value: PublicKey | Signer) => value is Signer;
export declare const deduplicateSigners: (signers: Signer[]) => Signer[];
export declare const generateSigner: (context: Pick<Context, 'eddsa'>) => Signer;
export declare const createSignerFromKeypair: (context: Pick<Context, 'eddsa'>, keypair: Keypair) => Signer;
export declare const createNoopSigner: (publicKey: PublicKey) => Signer;
export declare const createNullSigner: () => Signer;
export declare class NullSigner implements Signer {
    get publicKey(): PublicKey;
    signMessage(): Promise<Uint8Array>;
    signTransaction(): Promise<Transaction>;
    signAllTransactions(): Promise<Transaction[]>;
}
